@@ -62,12 +62,12 @@ class TestServer(unittest.TestCase):
 
     def test_metrics(self):
         for line in MESSAGE_TEXT.split("\n"):
-            prometheus(line)
+            prometheus(line, 0)
 
         handler = MockHandler()
         handler.path = "/metrics"
         handler.do_GET()
 
         handler.wfile.seek(0)
-        self.assertTrue(
-            "weather_temperature" in handler.wfile.read().decode("utf8"))
+        self.assertIn(
+            "prom433_temperature", handler.wfile.read().decode("utf8"))
